        function getT(rr,cc){
       if(rr==3 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==3 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 25 <br>2,4,6,8,15,18,19,21,24,25,26,27,32,36,37,38,39,40,41,43,44,45,46,47,50';}
       if(rr==3 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>31</strong> miembros: 21 <strong>control</strong><br>0,1,3,5,7,9,11,12,14,16,17,20,23,28,29,31,33,34,35,42,49';}
       if(rr==3 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>30</strong> miembros: 5 <br>10,13,22,30,48';}
       if(rr==17 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==17 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 25 <br>2,4,6,8,15,18,19,21,24,25,26,27,32,36,37,38,39,40,41,43,44,45,46,47,50';}
       if(rr==17 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>31</strong> miembros: 21 <strong>control</strong><br>0,1,3,5,7,9,11,12,14,16,17,20,23,28,29,31,33,34,35,42,49';}
       if(rr==17 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>30</strong> miembros: 5 <br>10,13,22,30,48';}
       if(rr==19 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==19 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 25 <br>2,4,6,8,15,18,19,21,24,25,26,27,32,36,37,38,39,40,41,43,44,45,46,47,50';}
       if(rr==19 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>31</strong> miembros: 21 <strong>control</strong><br>0,1,3,5,7,9,11,12,14,16,17,20,23,28,29,31,33,34,35,42,49';}
       if(rr==19 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>30</strong> miembros: 5 <br>10,13,22,30,48';}
       if(rr==20 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==20 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 25 <br>2,4,6,8,15,18,19,21,24,25,26,27,32,36,37,38,39,40,41,43,44,45,46,47,50';}
       if(rr==20 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>31</strong> miembros: 21 <strong>control</strong><br>0,1,3,5,7,9,11,12,14,16,17,20,23,28,29,31,33,34,35,42,49';}
       if(rr==20 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>30</strong> miembros: 5 <br>10,13,22,30,48';}
       if(rr==21 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==21 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 25 <br>2,4,6,8,15,18,19,21,24,25,26,27,32,36,37,38,39,40,41,43,44,45,46,47,50';}
       if(rr==21 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>31</strong> miembros: 21 <strong>control</strong><br>0,1,3,5,7,9,11,12,14,16,17,20,23,28,29,31,33,34,35,42,49';}
       if(rr==21 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>30</strong> miembros: 5 <br>10,13,22,30,48';}
       if(rr==22 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==22 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 25 <br>2,4,6,8,15,18,19,21,24,25,26,27,32,36,37,38,39,40,41,43,44,45,46,47,50';}
       if(rr==22 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>31</strong> miembros: 21 <strong>control</strong><br>0,1,3,5,7,9,11,12,14,16,17,20,23,28,29,31,33,34,35,42,49';}
       if(rr==22 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260620 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>30</strong> miembros: 5 <br>10,13,22,30,48';}
}
